/********************************************************************
 *                   NASA CONFIDENTIAL INFORMATION                  *
 *                 (c)2003 Nasa Ames Research Center				        *
 *                        All Rights Reserved                       *
 *                                                                  *
 *  This program contains confidential and proprietary information  *
 *  of NASA Ames Research Center, any reproduction, disclosure,     *
 *  or use in whole or in part is expressly prohibited, except as   *
 *  may be specifically authorized by prior written agreement.      *
 *                                                                  *
 ********************************************************************/
package brahms.base;

/**
 * The CalendarUtilGroup declares a set of activities that can be
 * used to retrieve and manipulate Calendar objects.
 *
 * @author Ron van Hoof
 * @version 13 August 2003
 */
group CalendarUtilGroup {
	activities:
		/**
		 * Creates a new Calendar object and initializes its beliefs with the
		 * current date and time based on the currently set or default
		 * time zone. In simulated mode the time will be initialized to
		 * the simulated date/time. In (distributed) real-time mode the
		 * actual system time is used.
		 *
		 * @return out an unbound variable of type Calendar to which to assign
		 *				the newly created Calendar object
		 */
		java getCurrentTime(Calendar out) {
			class: "brahms.base.util.GetCurrentTimeActivity";
		} // getCurrentTime
		
		/**
		 * Creates a new Calendar object and initializes its beliefs with the
		 * current date and time based on the currently set or default
		 * time zone. In simulated mode the time will be initialized to
		 * the simulated date/time unless the timeType is set to REAL_TIME in
		 * which case the system time is returned. In (distributed) real-time 
		 * mode always the actual system time is used regardless of whether the
		 * timeType is set to SIM_TIME (a warning will be generated in the vm.log
		 * file if SIM_TIME is set when this activity is called when the virtual
		 * machine is in (distributed) real-time mode.
		 *
		 * @param timeType one of SIM_TIME or REAL_TIME to indicate from what clock
		 *				the time should be returned, the internal simulation clock or the
		 *			  system clock.
		 * @return out an unbound variable of type Calendar to which to assign
		 *				the newly created Calendar object
		 */
		java getCurrentTime2(symbol timeType, Calendar out) {
			class: "brahms.base.util.GetCurrentTimeActivity";
		} // getCurrentTime2
		
		/**
		 * Determines based on the specified 'in' Calendar what tomorrow's date
		 * is and either assigns a new Calendar with that to the 'out' Calendar
		 * if an unbound variable is passed or populated the specified 'out'
		 * Calendar with the new date information.
		 *
		 * @param in the Calendar to use as the basis for tomorrow's date
		 * @return out the (new) Calendar populated with tomorrow's date information
		 */
		java getTomorrow(Calendar in, Calendar out) {
			class: "brahms.base.util.GetTomorrowActivity";
		} // getTomorrow

		/**
		 * Determines based on the specified 'in' Calendar what yesterday's date
		 * is and either assigns a new Calendar with that to the 'out' Calendar
		 * if an unbound variable is passed or populated the specified 'out'
		 * Calendar with the new date information.
		 *
		 * @param in the Calendar to use as the basis for yesterday's date
		 * @return out the (new) Calendar populated with yesterday's date information
		 */
		java getYesterday(Calendar in, Calendar out) {
			class: "brahms.base.util.GetYesterdayActivity";
		} // getYesterday
		
		/**
		 * Tests whether the specified date timestamp falls within the time period
		 * indicated by the timestamps startRange and endRange. If the date falls
		 * within that range true is returned, otherwise false it returned. The
		 * timestamps must be formatted as specified in the Calendar class.
		 *
		 * @param startRange the timestamp indicating the start of the date range
		 * @param endRange the timestamp indicating the end of the date range
		 * @param date the timestamp indicate the date to be tested
		 * @return out the boolean result, true if within range, false if not. This
		 * 			   parameter must be passed an unbound variable of type boolean.
		 */
		java inDateRange(string startRange, string endRange, string date, boolean out) {
			class: "brahms.base.util.InDateRangeActivity";
		} // inDateRange
		
		/**
		 * Converts the specified timeStamp into a (new) Calendar.
		 * If the specified Calendar is an existing Calendar then its
		 * date/time data will be replaced with that of the timeStamp.
		 * If the out parameter is passed a unassigned variable a new
		 * Calendar object will be created containing the date/time
		 * information. The timestamps must be formatted as specified in 
		 * the Calendar class.
		 *
		 * @param timeStamp the time stamp to be converted
		 * @return out the (new) Calendar populated with the timestamp's date information
		 */
		java getCalendar(string timeStamp, Calendar out) {
			class: "brahms.base.util.GetCalendarActivity";
		} // getCalendar
		
		/**
		 * Converts the specified Calendar into a timestamp.
		 * The timestamp is formatted as specified in the Calendar class.
		 *
		 * @param in the Calendar to be converted
		 * @return out the timestamp
		 */
		java getTimeStamp(Calendar in, string out) {
			class: "brahms.base.util.GetTimeStampActivity";
		} // getTimeStamp
		
		/**
		 * Converts the specified in Calendar to a (Calendar) in the specified
		 * timeZone. If out is passed a valid Calendar, then its contents will
		 * be replaced with the date/time in the new timezone. If an unbound
		 * variable is passed to the out parameter a new Calendar will be
		 * created with the date/time information in the specified timezone.
		 *
		 * @param in the Calendar to be used as the basis for the conversion
		 * @param timeZone the time zone to convert to, must be its full name
		 * @param out the (new) Calendar populated with the date/time in the new time zone.
		 */
		java convertToTimeZone(Calendar in, string timeZone, Calendar out) {
			class: "brahms.base.util.ConvertToTimeZoneActivity";
		} // convertToTimeZone
		
		/**
		 * Adds a specified amount of time to the specified time field
		 * to the specified in Calendar. If out is passed a valid Calendar, 
		 * then its contents will be replaced with the adjusted date/time. 
		 * If an unbound variable is passed to the out parameter a new Calendar 
		 * will be created with the adjusted date/time information.
		 *
		 * The valid fields consist of the following symbols:
		 *		YEAR, MONTH, DATE, HOUR, MINUTE, SECOND, MILLISECOND
		 *
		 * @param in the Calendar to be used as the basis for the time adjustment
		 * @param field the time field to be adjusted
		 * @param amount the amount of time to be adjusted
		 * @param out the adjusted date/time
		 */
		java addTime(Calendar in, symbol field, int amount, Calendar out) {
			class: "brahms.base.util.AddTimeActivity";
		} // addTime
		
} // CalendarUtilGroup