/********************************************************************
 *                   NASA CONFIDENTIAL INFORMATION                  *
 *                 (c)2002 Nasa Ames Research Center		    *
 *                        All Rights Reserved                       *
 *                                                                  *
 *  This program contains confidential and proprietary information  *
 *  of NASA Ames Research Center, any reproduction, disclosure,     *
 *  or use in whole or in part is expressly prohibited, except as   *
 *  may be specifically authorized by prior written agreement.      *
 *                                                                  *
 ********************************************************************/
package brahms.base;

/**
 * This class provides a set of generic activities that can be used
 * by a model builder for writing info messages to a log file.
 *
 * @author Ron van Hoof
 * @version 18 July 2002
 */
class SystemClass {

	activities:
		/**
		 * Prints all the beliefs for the agent performing this
		 * activity about the specified concept and specified attribute
		 * or relation.
		 *
		 * @param aboutConcept the concept about which the belief is to be printed
		 * @param aboutAttribute the name of the attribute or relation
		 * @param aboutAttributeType one of 'attribute' or 'relation' to indicate
		 * 	  whether the aboutAttribute name is the name of an attribute or
		 *	  relation
		 */
		java printBelief(Concept aboutConcept, symbol aboutAttribute, symbol aboutAttributeType) {
		  class: "brahms.base.system.PrintBeliefActivity";
		} // printBelief
		
		/**
		 * Prints all the facts in the world about the specified concept and 
		 * specified attribute or relation.
		 *
		 * @param aboutConcept the concept about which the belief is to be printed
		 * @param aboutAttribute the name of the attribute or relation
		 * @param aboutAttributeType one of 'attribute' or 'relation' to indicate
		 * 	  whether the aboutAttribute name is the name of an attribute or
		 *	  relation
		 */
		java printFact(Concept aboutConcept, symbol aboutAttribute, symbol aboutAttributeType) {
		  class: "brahms.base.system.PrintFactActivity";
		} // printFact
		
		/**
		 * Prints the specified message to the log file.
		 *
		 * Note that for any of the println activities an output parameter
		 * declared as 'string out' can be declared to put the results
		 * of the string message in the output parameter instead
		 * of writing it to the log. This can be especially useful
		 * when using parameters within the message.
		 *
		 * @param message the message to be printed in the log file.
		 */
		java println(string message) {
		  class: "brahms.base.system.PrintlnActivity";
		} // println

		/**
		 * Prints the specified message to the log file and allows for
		 * one variable of type Concept. The concept indicated by the
		 * p1 parameter can be placed within the message string at a
		 * position marked as %1. For example:
		 *    "Agent '%1' is executing activity MyActivity"
		 * The %1 variable will be replaced with the fully qualified
		 * name of the concept passed to p1.
		 *
		 * Note that for any of the println activities an output parameter
		 * declared as 'string out' can be declared to put the results
		 * of the string message in the output parameter instead
		 * of writing it to the log. This can be especially useful
		 * when using parameters within the message.
		 *
		 * @param message the message to be printed in the log file.
		 * @param p1 the concept to replace the %1 variable
		 */
		java println_c(string message, Concept p1) {
		  class: "brahms.base.system.PrintlnActivity";
		} // println_c
		
		/**
		 * Prints the specified message to the log file and allows for
		 * one variable of type int. The int indicated by the
		 * p1 parameter can be placed within the message string at a
		 * position marked as %1. For example:
		 *    "The duration of activity MyActivity=%1"
		 * The %1 variable will be replaced with the integer value 
		 * passed to p1.
		 *
		 * Note that for any of the println activities an output parameter
		 * declared as 'string out' can be declared to put the results
		 * of the string message in the output parameter instead
		 * of writing it to the log. This can be especially useful
		 * when using parameters within the message.
		 *
		 * @param message the message to be printed in the log file.
		 * @param p1 the int to replace the %1 variable
		 */
		java println_n(string message, int p1) {
		  class: "brahms.base.system.PrintlnActivity";
		} // println_n
		
		/**
		 * Prints the specified message to the log file and allows for
		 * one variable of type double. The double value indicated by the
		 * p1 parameter can be placed within the message string at a
		 * position marked as %1. For example:
		 *    "The total cost=%1"
		 * The %1 variable will be replaced with the double value 
		 * passed to p1.
		 *
		 * Note that for any of the println activities an output parameter
		 * declared as 'string out' can be declared to put the results
		 * of the string message in the output parameter instead
		 * of writing it to the log. This can be especially useful
		 * when using parameters within the message.
		 *
		 * @param message the message to be printed in the log file.
		 * @param p1 the double to replace the %1 variable
		 */
		java println_d(string message, double p1) {
		  class: "brahms.base.system.PrintlnActivity";
		} // println_d
		
		/**
		 * Prints the specified message to the log file and allows for
		 * one variable of type boolean. The boolean indicated by the
		 * p1 parameter can be placed within the message string at a
		 * position marked as %1. For example:
		 *    "Agent X is available=%1"
		 * The %1 variable will be replaced with the boolean value
		 * passed to p1.
		 *
		 * Note that for any of the println activities an output parameter
		 * declared as 'string out' can be declared to put the results
		 * of the string message in the output parameter instead
		 * of writing it to the log. This can be especially useful
		 * when using parameters within the message.
		 *
		 * @param message the message to be printed in the log file.
		 * @param p1 the boolean to replace the %1 variable
		 */
		java println_b(string message, boolean p1) {
		  class: "brahms.base.system.PrintlnActivity";
		} // println_b
		
		/**
		 * Prints the specified message to the log file and allows for
		 * one variable of type string or symbol. The value indicated by the
		 * p1 parameter can be placed within the message string at a
		 * position marked as %1. For example:
		 *    "Agent is executing activity %1"
		 * The %1 variable will be replaced with the string passed to p1.
		 *
		 * Note that for any of the println activities an output parameter
		 * declared as 'string out' can be declared to put the results
		 * of the string message in the output parameter instead
		 * of writing it to the log. This can be especially useful
		 * when using parameters within the message.
		 *
		 * @param message the message to be printed in the log file.
		 * @param p1 the string to replace the %1 variable
		 */
		java println_s(string message, string p1) {
		  class: "brahms.base.system.PrintlnActivity";
		} // println_s
		
} // SystemClass
