/********************************************************************
 *                   NASA CONFIDENTIAL INFORMATION                  *
 *                 (c)2000 Nasa Ames Research Center				        *
 *                        All Rights Reserved                       *
 *                                                                  *
 *  This program contains confidential and proprietary information  *
 *  of NASA Ames Research Center, any reproduction, disclosure,     *
 *  or use in whole or in part is expressly prohibited, except as   *
 *  may be specifically authorized by prior written agreement.      *
 *                                                                  *
 ********************************************************************/
package gov.nasa.arc.brahms.jact.string;

import gov.nasa.arc.brahms.vm.api.jac.AbstractExternalActivity;
import gov.nasa.arc.brahms.vm.api.exceptions.*;
import gov.nasa.arc.brahms.vm.api.common.*;

/**
 * The ConcatActivity is an external activity that can be used
 * in Brahms Java Activities. This activity allows for the
 * concatenation of two string or symbols. The activity requires
 * the following three parameters to be defined:
 * <ul>
 *   <li> in1 - a string or symbol at the beginning of the concat result</li>
 *   <li> in2 - a string or symbol to be concatenated to in1 at the end</li>
 *   <li> out - an unbound variable of type string or symbol that will contain the result</li>
 * </ul>
 *
 * @author Ron van Hoof
 * @version 14 September 2000
 */
public class ConcatActivity extends AbstractExternalActivity {
  /*
   * Constructors
   */
  /**
   * Creates a new ConcatActivity, must have an parameter-less
   * constructor for the VM.
   */
  public ConcatActivity() {
  } // ConcatActivity

  /*
   * Instance Attributes
   */


  /*
   * Instance Methods
   */
  /**
   * Implement the activity
   *
   * @exception ExternalException if an internal error occurs
   */
  public final void doActivity() throws ExternalException {
    // note that any of these functions will throw an exception if either
    // a parameter cannot be found, the parameter is of an invalid type,
    // or the variable is already bound. We're not handling the
    // exceptions here individually, but we could.

    // get the required parameters for the activity
    IParameter oIn1 = getParameter("in1");
    IParameter oIn2 = getParameter("in2");
    IParameter oOut = getParameter("out");

    // get the parameter values, input parameters could be string values
    // or variables containing the values.
    // first get variable
    IVariable oOutVar = oOut.getVariableValue();

    // get string input parameters
    String sIn1;
    switch (oIn1.getContentType()) {
      case IParameter.VARIABLE: {
        sIn1 = oIn1.getVariableValue().getStringValue();
        break;
      } // VARIABLE
      case IParameter.STRING:
      case IParameter.SYMBOL: {
        sIn1 = oIn1.getStringValue();
        break;
      } // STRING, SYMBOL
      default: {
        // set an empty result in the output variable so that elements relying on
        // a value won't fail
        if (!oOutVar.isBound())
          oOutVar.setValue("");
        throw new ExternalException("Invalid type for the first input parameter, must be 'string' or 'symbol'");
      } // default
    } // end switch

    String sIn2;
    switch (oIn2.getContentType()) {
      case IParameter.VARIABLE: {
        sIn2 = oIn2.getVariableValue().getStringValue();
        break;
      } // VARIABLE
      case IParameter.STRING:
      case IParameter.SYMBOL: {
        sIn2 = oIn2.getStringValue();
        break;
      } // STRING, SYMBOL
      default: {
        // set an empty result in the output variable so that elements relying on
        // a value won't fail
        if (!oOutVar.isBound())
          oOutVar.setValue("");
        throw new ExternalException("Invalid type for the second input parameter, must be 'string' or 'symbol'");
      } // default
    } // end switch

    // set the result in the unassigned variable
    oOutVar.setValue(sIn1+sIn2);
  } // doActivity

} // ConcatActivity