/********************************************************************
 *                   NASA CONFIDENTIAL INFORMATION                  *
 *                 (c)2002 Nasa Ames Research Center				        *
 *                        All Rights Reserved                       *
 *                                                                  *
 *  This program contains confidential and proprietary information  *
 *  of NASA Ames Research Center, any reproduction, disclosure,     *
 *  or use in whole or in part is expressly prohibited, except as   *
 *  may be specifically authorized by prior written agreement.      *
 *                                                                  *
 ********************************************************************/
package gov.nasa.arc.brahms.maa.test;

import gov.nasa.arc.brahms.vm.api.jagt.*;
import gov.nasa.arc.brahms.vm.api.common.*;
import gov.nasa.arc.brahms.vm.api.exceptions.*;

/**
 * The ExternalAgentTemplate is an empty shell for external
 * agents. It does not perform any tasks. The tasks have to
 * implemented by the developer.
 *
 * @author Ron van Hoof
 * @version 15 April 2002
 */
public class ExternalAgentTemplate extends AbstractExternalAgent {

  /*
   * Constants
   */
  private final static byte STOPPED = 0;
  private final static byte STARTED = 1;

  /*
   * Constructors
   */
  /**
   * Constructor, creates a new ExternalAgentTemplate
   */
  public ExternalAgentTemplate() {
  } // ExternalAgentTemplate

  /*
   * Instance Attributes
   */
  /** Indicates the state of the agent, started or stopped */
  private byte          m_btState;
  /** Lock used to prevent access to the state attribute by more then one thread at the same time */
  private int[]         m_oStateLock;

  /*
   * Instance Methods
   */
  /**
   * Initialize is used to initialize the external agent after it has been
   * loaded into the virtual machine. All agents are initialized before they
   * are started.
   *
   * @exception ExternalException if an internal error occurs.
   */
  public void initialize() throws ExternalException {
    m_btState = STOPPED;
    m_oStateLock = new int[1];

    // custom external agent initialization code goes here
  } // initialize

  /**
   * Starts the external agent. Any initializations required for running the
   * agent are to be performed here.
   *
   * @exception ExternalException if an internal error occurs.
   */
  public void start() throws ExternalException {
    synchronized(m_oStateLock) {
	  if (m_btState == STARTED)
		return;

	  // custom external agent start code goes here

      m_btState = STARTED;
      m_oStateLock.notify();
    } // end synchronized
  } // start

  /**
   * Pauses the external agent.
   *
   * @exception ExternalException if an internal error occurs.
   */
  public void pause() throws ExternalException {
  } // pause

  /**
   * Resumes the external agent from a pause.
   *
   * @exception ExternalException if an internal error occurs.
   */
  public void resume() throws ExternalException {
  } // resume

  /**
   * Stops the external agent. Here clean-up is to be performed for the run-time
   * state of the external agent.
   *
   * @exception ExternalException if an internal error occurs.
   */
  public void stop() throws ExternalException {
    synchronized(m_oStateLock) {
	  if (m_btState == STOPPED)
		return;

	  // custom external agent stop code goes here

      m_btState = STOPPED;
      m_oStateLock.notify();
    } // end synchronized
  } // stop

  /**
   * Resets the external agent to the initialized state as it was placed in
   * using the initialize method, performing any additional clean-up if
   * necessary.
   *
   * @exception ExternalException if an internal error occurs.
   */
  public void reset() throws ExternalException {
    synchronized(m_oStateLock) {
      m_btState = STOPPED;
      m_oStateLock.notify();
    } // end synchronized
  } // reset

  /**
   * The virtual machine takes care of having the agent run in its own thread of
   * execution.
   *
   * @exception ExternalException if an unrecoverable error occurs.
   */
  public void doWork() throws ExternalException {
    byte btState = STOPPED;

    // we're going to keep the agent alive for it to receive any incoming beliefs
    // and or facts.
    synchronized(m_oStateLock) {
      btState = m_btState;
    } // end synchronized
    while (btState == STARTED) {

	  // custom external agent code goes here, if no work is performed in a thread
	  // by the external agent then leave the code below (the sleep code) in
	  // place. It is used to keep the agent alive so it can receive incoming
	  // communications.
      try {
	    Thread.currentThread().sleep(100);
      } catch (InterruptedException e) {
      } // end try

	  // refresh the state
      synchronized(m_oStateLock) {
        btState = m_btState;
      } // end synchronized
    } // end while
  } // doWork

  /**
   * onReceive is called by the virtual machine whenever a new belief is
   * communicated to the external agent by another agent or object.
   * Processing the actual incoming belief is optional.
   *
   * @param belief the IBelief communicated to this external agent
   * @exception ExternalException if an error occurs handling this belief
   */
  public void onReceive(IBelief belief) throws ExternalException {
    getVMController().getLogger().info("ExternalAgentTemplate - Received: "+belief);
  } // onReceive

  /**
   * onAssert is called by the virtual machine whenever a new fact is
   * asserted in the world state. If the external agent concludes a new
   * fact this external agent is also guaranteed to be notified that
   * the fact is actually asserted through a call to this method.
   * Processing the assertion is optional.
   *
   * @param fact the IFact asserted in the world state
   * @exception ExternalException if an error occurs handling this fact
   */
  public void onAssert(IFact fact) throws ExternalException {
    getVMController().getLogger().info("ExternalAgentTemplate - Assert notification: "+fact);
  } // onAssert

  /**
   * onRetract is called by the virtual machine whenever a fact is
   * retracted from the world state. If the external agent retracts
   * a fact from the world state this external agent is also guaranteed
   * to be notified that the fact is actually retracted through a call
   * to this method. Processing the retraction is optional.
   *
   * @param fact the IFact retracted from the world state
   * @exception ExternalException if an error occurs handling this fact
   */
  public void onRetract(IFact fact) throws ExternalException {
    getVMController().getLogger().info("ExternalAgentTemplate - Retract notification: "+fact);
  } // onRetract

} // ExternalAgentTemplate
